from setuptools import setup
setup(name='hykpyp',
      version='0.1',
      description='this is demo',
      url='https://github.com/hykfft/hykpyp',
      author='hyk',
      author_email='hykfft@gmail.com',
      license='MIT',
      packages=[],
      zip_safe=False)
